% Copyright Michael Sargent 2015
% 
% Solves the system of ODEs and PDEs that describe the growth of a bubble
% in an generalised Newtonian fluid, where the concentration, position and
% temperature of the fluid can vary with time and space. These are the
% three parts of the model which give it the name "three part model".

% Start with a clean slate.
clear all
close all
clc

%%
% Solve it, while profiling. The argument of TPM_setup is the savename.
profile on

% default parameters
[N,coeffs,model,savename]   = TPM_setup('results');

% change the initial bubble size and boundary condition functions
coeffs.R0 = 10*10^(-6);             % bubble radius         % m
coeffs.Tf = @(t) 373 + t * 0;       % temperature function  % (s) K
coeffs.Pf = @(t) 2e6 + t * 0;       % pressure function     % (s) Pa

% recalculate S0 and C0 based on the new initial conditions
coeffs.S0 =     coeffs.R0 * coeffs.ratio;
coeffs.C0 =     (coeffs.Pf(0)+2*coeffs.sigma/coeffs.R0)*coeffs.KH;

% solve it
[t,Y]                       = TPM_solver( N, coeffs, model );

% save the results
[results,runtime]           = TPM_results( N, coeffs, model, t,Y,savename);

profile viewer
profile off

