classdef molten_coffee < carreauyasuda_fluid 
    % Copyright Michael Sargent 2015
    %
    % MOLTEN_COFFEE is the fluid model which is used to describe the molten
    % instant coffee in the three part bubble growth model. It is currently
    % a temperature dependent carreaut yasuda fluid with a thinning
    % parameter of 0.680, which is expected to solidify at 72 'C (345 K).
    % It is assumed that the prefactor for the temperature dependence is
    % 3915 Pa s, which would be the zero shear viscosity at infinite
    % temperature. The Andrade-type exponent is 33.5 K.
    
    %%
    methods
        %%
        function [ obj ] = molten_coffee()
            % Creates a carreauyasuda_fluid object, then initialises
            % different values.
            obj@carreauyasuda_fluid();
            
            % Transition time
            obj.lambda = 2.117;
            
            % Transition sharpness
            obj.a = 0.839;
            
            % Thinning parameter
            obj.n = 0.680;
            
            % High shear viscosity
            obj.etaInf = 0;
            
            % Low shear viscosity (at T -> inf)
            obj.A_eta = 3915;
            
            % Solidification temperature
            obj.T_s = 345;
            
            % Exponent.
            obj.B_eta = 33.5;
            
        end
    end
end